<?php
/**
 * Customizer default options
 *
 * @package Theme Palace
 * @subpackage  ultra_gym
 * @since  ultra_gym 1.0.0
 * @return array An array of default values
 */

function ultra_gym_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$ultra_gym_default_options = array(
		// Color Options
		'header_title_color'			    => '#000',
		'header_tagline_color'			    => '#000',
		'header_txt_logo_extra'			    => 'show-all',

		// breadcrumb
		'breadcrumb_enable'				    => (bool) true,
		'breadcrumb_separator'			    => '/',
		
		// layout 
		'site_layout'         			    => 'wide',
		'sidebar_position'         		    => 'right-sidebar',
		'post_sidebar_position' 		    => 'right-sidebar',
		'page_sidebar_position' 		    => 'right-sidebar',
		'menu_sticky'					    => (bool) false,

		// excerpt options
		'long_excerpt_length'               => 25,
		'read_more_text'           		    => esc_html__( 'Read More', 'ultra-gym' ),

		// pagination options
		'pagination_enable'         	    => (bool) true,
		'pagination_type'         		    => 'default',

		// footer options
		'copyright_text'           		    => sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s. ', '1: Year, 2: Site Title with home URL', 'ultra-gym' ), '[the-year]', '[site-link]' ) . esc_html__( 'All Rights Reserved | ', 'ultra-gym' ) . esc_html( $theme_data->get( 'Name') ) . '&nbsp;' . esc_html__( 'by', 'ultra-gym' ). '&nbsp;<a target="_blank" href="'. esc_url( $theme_data->get( 'AuthorURI' ) ) .'">'. esc_html( ucwords( $theme_data->get( 'Author' ) ) ) .'</a>',

		// reset options
		'reset_options'      			    => (bool) false,
		
		// homepage sections sortable
		'sortable' 						    => 'slider,about,service,testimonial,blog',

		// blog/archive options
		'your_latest_posts_title' 		    => esc_html__( 'Blogs', 'ultra-gym' ),
		'hide_date' 					    => (bool) false,
		'hide_author' 					    => (bool) false,


		// single post theme options
		'single_post_hide_date' 		    => (bool) false,
		'single_post_hide_author'		    => (bool) false,

		/* Front Page */

		// Slider
		'slider_section_enable'				=> (bool) false,
		'slider_social_menu_enable'			=> (bool) true,
		'slider_autoplay_enable'			=> (bool) false,
		'slider_btn_txt'                    => esc_html__('Join Club','ultra-gym'),

		//about 
		'about_section_enable'			    => (bool) false,
		'about_section_title'				=> esc_html__('Featured Content','ultra-gym'),
		'about_btn_label'					=> esc_html__('Explore More','ultra-gym'),

		//service
		'service_section_enable'		    => (bool) false,
		'service_section_sub_title'			=> esc_html__( 'Our Services', 'ultra-gym' ),
		'service_section_title'			    => esc_html__( 'Training & Exercise', 'ultra-gym' ),

		//testimonial
        'testimonial_section_enable'        => (bool) false,
		'testimonial_section_sub_title'     => esc_html__('Testimonial','ultra-gym'),
		'testimonial_section_title'	        => esc_html__('Our Happy Clients','ultra-gym'),
		
		// blog
		'blog_section_enable'			    => (bool) false,
		'blog_sub_title'          			=> esc_html__('Blog','ultra-gym'),
		'blog_title'					    => esc_html__( 'Amazing Articles', 'ultra-gym' ),
		'blog_post_read_more_btn_label'	    => esc_html__( 'Read More', 'ultra-gym' ),
	
	);

	$output = apply_filters( 'ultra_gym_default_theme_options', $ultra_gym_default_options );

	// Sort array in ascending order, according to the key:
	if ( ! empty( $output ) ) {
		ksort( $output );
	}

	return $output;
}