<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage  ultra_gym
 * @since  ultra_gym 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function ultra_gym_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'ultra-gym' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function ultra_gym_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'ultra-gym' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    wp_reset_postdata();
    return  $choices;
}

/**
 * List of category for category choices.
 * @return Array Array of post ids and name.
 */
function ultra_gym_category_choices() {
    $tax_args = array(
        'hierarchical' => 0,
        'taxonomy'     => 'category',
    );
    $taxonomies = get_categories( $tax_args );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'ultra-gym' );
    foreach ( $taxonomies as $tax ) {
        $choices[ $tax->term_id ] = $tax->name;
    }
    return  $choices;
}


if ( ! function_exists( 'ultra_gym_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function ultra_gym_site_layout() {
        $ultra_gym_site_layout = array(
            'wide'          => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout'  => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'ultra_gym_site_layout', $ultra_gym_site_layout );
        return $output;
    }
endif;

if ( ! function_exists( 'ultra_gym_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function ultra_gym_selected_sidebar() {
        $ultra_gym_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'ultra-gym' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'ultra-gym' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'ultra-gym' ),
        );

        $output = apply_filters( 'ultra_gym_selected_sidebar', $ultra_gym_selected_sidebar );

        return $output;
    }
endif;


if ( ! function_exists( 'ultra_gym_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function ultra_gym_global_sidebar_position() {
        $ultra_gym_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'ultra_gym_global_sidebar_position', $ultra_gym_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'ultra_gym_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function ultra_gym_sidebar_position() {
        $ultra_gym_sidebar_position = array(
            'right-sidebar'         => get_template_directory_uri() . '/assets/images/right.png',
            'no-sidebar'            => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'ultra_gym_sidebar_position', $ultra_gym_sidebar_position );

        return $output;
    }
endif;

if ( ! function_exists( 'ultra_gym_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function ultra_gym_pagination_options() {
        $ultra_gym_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'ultra-gym' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'ultra-gym' ),
        );

        $output = apply_filters( 'ultra_gym_pagination_options', $ultra_gym_pagination_options );

        return $output;
    }
endif;


if ( ! function_exists( 'ultra_gym_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function ultra_gym_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'ultra-gym' ),
            'off'       => esc_html__( 'Disable', 'ultra-gym' )
        );
        return apply_filters( 'ultra_gym_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'ultra_gym_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function ultra_gym_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'ultra-gym' ),
            'off'       => esc_html__( 'No', 'ultra-gym' )
        );
        return apply_filters( 'ultra_gym_hide_options', $arr );
    }
endif;
