<?php
/**
 * Banner section
 *
 * This is the template for the content of about section
 *
 * @package Theme Palace
 * @subpackage  ultra_gym
 * @since  ultra_gym 1.0.0
 */
if ( ! function_exists( 'ultra_gym_add_about_section' ) ) :
    /**
    * Add about section
    *
    *@since  ultra_gym 1.0.0
    */
    function ultra_gym_add_about_section() {
    	$options = ultra_gym_get_theme_options();
        // Check if about is enabled on frontpage
        $about_enable = apply_filters( 'ultra_gym_section_status', true, 'about_section_enable' );

        if ( true !== $about_enable ) {
            return false;
        }
        // Get about section details
        $section_details = array();
        $section_details = apply_filters( 'ultra_gym_filter_about_section_details', $section_details );
        if ( empty( $section_details ) ) {
            return ;
        }

        // Render about section now.
        ultra_gym_render_about_section( $section_details );
    }
endif;

if ( ! function_exists( 'ultra_gym_get_about_section_details' ) ) :
    /**
    * about section details.
    *
    * @since  ultra_gym 1.0.0
    * @param array $input about section details.
    */
    function ultra_gym_get_about_section_details( $input ) {
        $options = ultra_gym_get_theme_options();

        $content = array();
        $page_id = '';
        if ( ! empty( $options['about_content_page'] ) )
            $page_id = isset($options['about_content_page']) ? $options['about_content_page'] : '' ;
        $args = array(
            'post_type'             => 'page',
            'p'                     =>  absint( $page_id ),
            'ignore_sticky_posts'   => true,
            );

        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['content']   = ultra_gym_trim_content(30);
                $page_post['subtitle']  = !empty($options['about_section_title'])? $options['about_section_title']: esc_html__('Featured Content','ultra-gym');
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'medium_large' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';
                $page_post['url']       = get_the_permalink( );
                $page_post['title']     = get_the_title();
                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// about section content details.
add_filter( 'ultra_gym_filter_about_section_details', 'ultra_gym_get_about_section_details' );


if ( ! function_exists( 'ultra_gym_render_about_section' ) ) :
  /**
   * Start about section
   *
   * @return string about content
   * @since  ultra_gym 1.0.0
   *
   */
   function ultra_gym_render_about_section( $content_details = array() ) {
        $options        = ultra_gym_get_theme_options();
        
        if ( empty( $content_details ) ) {
            return;
        } ?>

        <?php $content = $content_details[0]; ?>

        <div id="about-us">
            <div class="wrapper">
                <article class="has-post-thumbnail">

                        <div class="featured-image" style="background-image: url('<?php echo esc_url($content['image']); ?>');">
                            <a href="<?php echo esc_url($content['url']); ?>" class="post-thumbnail-link" title="<?php echo esc_attr($content['title']); ?>"></a>
                        </div><!-- .featured-image -->
                    
                    <div class="entry-container">

                        <div class="section-header">
                            <p class="section-subtitle"><?php echo esc_html($content['subtitle']); ?></p>
                            <h2 class="section-title"><?php echo esc_html($content['title']); ?></h2>
                        </div><!-- .section-header -->

                        <div class="entry-content">
                            <p><?php echo wp_kses_post($content['content']); ?></p>
                        </div><!-- .entry-content -->

                        <?php if(!empty($options['about_btn_label']) && !empty($content['url']) ): ?>
                            <div class="read-more">
                                <a href="<?php echo esc_url($content['url']); ?>" class="btn"><?php echo esc_html($options['about_btn_label'])?></a>
                            </div><!-- .read-more -->
                        <?php endif; ?>

                    </div><!-- .entry-container -->
                    
                </article>
            </div><!-- .wrapper -->
        </div><!-- #about-us -->
    <?php
    }    
endif; ?>
