<?php
/**
 * Services section
 *
 * This is the template for the content of service section
 *
 * @package Theme Palace
 * @subpackage  ultra_gym
 * @since  ultra_gym 1.0.0
 */
if ( ! function_exists( 'ultra_gym_add_service_section' ) ) :
    /**
    * Add service section
    *
    *@since  ultra_gym 1.0.0
    */
    function ultra_gym_add_service_section() {
    	$options = ultra_gym_get_theme_options();
        // Check if service is enabled on frontpage
        $service_enable = apply_filters( 'ultra_gym_section_status', true, 'service_section_enable' );

        if ( true !== $service_enable ) {
            return false;
        }
        // Get service section details
        $section_details = array();
        $section_details = apply_filters( 'ultra_gym_filter_service_section_details', $section_details );

        if ( empty( $section_details ) ) {
            return;
        }

        // Render service section now.
        ultra_gym_render_service_section( $section_details );
    }
endif;

if ( ! function_exists( 'ultra_gym_get_service_section_details' ) ) :
    /**
    * service section details.
    *
    * @since  ultra_gym 1.0.0
    * @param array $input service section details.
    */
    function ultra_gym_get_service_section_details( $input ) {
        $options = ultra_gym_get_theme_options();

        $content = array();
        $page_ids = array();

        for ( $i = 1; $i <= 3; $i++ ) {
            if ( ! empty( $options['service_content_page_' . $i] ) )
                $page_ids[] = $options['service_content_page_' . $i];
        }

        $args = array(
            'post_type'         => 'page',
            'post__in'          => ( array ) $page_ids,
            'posts_per_page'    => absint( 3 ),
            'orderby'           => 'post__in',
        );                    
      
        // Run The Loop.
        $query = new WP_Query( $args );
        if ( $query->have_posts() ) : 
            while ( $query->have_posts() ) : $query->the_post();
                $page_post['id']        = get_the_id();
                $page_post['title']     = get_the_title();
                $page_post['content']   = ultra_gym_trim_content(10);
                $page_post['url']       = get_the_permalink();
                $page_post['author']    = ultra_gym_author();
                $page_post['image']     = has_post_thumbnail() ? get_the_post_thumbnail_url( get_the_id(), 'full' ) : get_template_directory_uri() . '/assets/uploads/no-featured-image-600x450.jpg';

                // Push to the main array.
                array_push( $content, $page_post );
            endwhile;
        endif;
        wp_reset_postdata();

        if ( ! empty( $content ) ) {
            $input = $content;
        }
        return $input;
    }
endif;
// service section content details.
add_filter( 'ultra_gym_filter_service_section_details', 'ultra_gym_get_service_section_details' );


if ( ! function_exists( 'ultra_gym_render_service_section' ) ) :
  /**
   * Start service section
   *
   * @return string service content
   * @since  ultra_gym 1.0.0
   *
   */
   function ultra_gym_render_service_section( $content_details = array() ) {
        $options    = ultra_gym_get_theme_options();
        $service_sub_title  = $options['service_section_sub_title'];
        $service_title      = isset($options['service_section_title']) ? $options['service_section_title']: '';
        $service_bg_image   = (!empty($options['service_bg_image'])) ? $options['service_bg_image']: '';

        if ( empty( $content_details ) ) {
            return;
        } ?>

        <div id="our-services" class="page-section" style="background-image: url('<?php echo esc_url($service_bg_image); ?>');">
            <div class="wrapper">
                <div class="section-header">
                    <p class="section-subtitle"><?php echo esc_html($service_sub_title); ?></p>
                    <h2 class="section-title"><?php echo esc_html($service_title); ?></h2>
                </div>

                <div class="section-content col-3 clear">
                    <?php foreach ( $content_details as $i=>$content ) : ?>
                        <article>
                            <div class="service-item-wrapper">
                                <div class="service-icon">
                                    <a href="<?php echo esc_url($content['url']); ?>" title="<?php echo esc_attr($options['title']); ?>">
                                        <svg viewBox="0 -21 512.016 512">
                                            <path d="m234.667969 469.339844c-129.386719 0-234.667969-105.277344-234.667969-234.664063s105.28125-234.6679685 234.667969-234.6679685c44.992187 0 88.765625 12.8203125 126.589843 37.0976565 7.425782 4.78125 9.601563 14.679687 4.820313 22.125-4.796875 7.445312-14.675781 9.597656-22.121094 4.820312-32.640625-20.972656-70.441406-32.042969-109.289062-32.042969-111.746094 0-202.667969 90.921876-202.667969 202.667969 0 111.742188 90.921875 202.664063 202.667969 202.664063 111.742187 0 202.664062-90.921875 202.664062-202.664063 0-6.679687-.320312-13.292969-.9375-19.796875-.851562-8.8125 5.589844-16.621094 14.378907-17.472656 8.832031-.8125 16.617187 5.589844 17.472656 14.378906.722656 7.53125 1.085937 15.167969 1.085937 22.890625 0 129.386719-105.277343 234.664063-234.664062 234.664063zm0 0"></path><path d="m261.332031 288.007812c-4.09375 0-8.191406-1.558593-11.304687-4.691406l-96-96c-6.25-6.253906-6.25-16.386718 0-22.636718s16.382812-6.25 22.632812 0l84.695313 84.695312 223.335937-223.339844c6.253906-6.25 16.386719-6.25 22.636719 0s6.25 16.382813 0 22.632813l-234.667969 234.667969c-3.136718 3.113281-7.230468 4.671874-11.328125 4.671874zm0 0"></path>
                                        </svg>      
                                    </a>
                                </div><!-- .service-icon -->

                                <header class="entry-header">
                                    <h2 class="entry-title"><a href="<?php echo esc_url($content['url']); ?>"><?php echo esc_html($content['title']); ?></a></h2>
                                </header>

                                <div class="entry-content">
                                    <p><?php echo wp_kses_post($content['content']); ?></p>
                                </div><!-- .entry-content -->
                            </div><!-- .service-item-wrapper -->
                        </article>
                    <?php endforeach; ?>

                </div><!-- .section-content -->
            </div><!-- .wrapper -->
        </div><!-- our-services -->

    <?php
    }    
endif; ?>
